
def show_music(index,music_name,authors):
    print(str(index) + "\t" + music_name + "\t" + authors)

def show_title():
    print("Index\tMusicName\tMusicAuthor")

def show_out_of_bound():
    print('越界错误')